@@ -1,22 +1,19 @@
 #!/usr/bin/env bash
 
-if [[ "$(uname)" == "Darwin" ]]; then
+if [[ "$target_platform" == osx-* ]]; then
     export ENABLE_QUADMATH=no
-    export AR_CMAKE_SETTING=
-    export RANLIB_CMAKE_SETTING=
     # Workaround for missing C++17 feature when building the tests.
     export CXXFLAGS="$CXXFLAGS -DCATCH_CONFIG_NO_CPP17_UNCAUGHT_EXCEPTIONS"
+elif [[ "$target_platform" == linux-aarch64 ||  "$target_platform" == linux-ppc64le ]]; then
+    export ENABLE_QUADMATH=no
 else
     export ENABLE_QUADMATH=yes
-    # Workaround for making the LTO machinery work on Linux.
-    export AR_CMAKE_SETTING="-DCMAKE_CXX_COMPILER_AR=$GCC_AR -DCMAKE_C_COMPILER_AR=$GCC_AR"
-    export RANLIB_CMAKE_SETTING="-DCMAKE_CXX_COMPILER_RANLIB=$GCC_RANLIB -DCMAKE_C_COMPILER_RANLIB=$GCC_RANLIB"
 fi
 
 mkdir build
 cd build
 
-cmake \
+cmake ${CMAKE_ARGS} \
     -DCMAKE_CXX_STANDARD=17 \
     -DCMAKE_BUILD_TYPE=Release \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
@@ -29,13 +26,13 @@ cmake \
     -DBoost_NO_BOOST_CMAKE=ON \
     -DMPPP_BUILD_TESTS=yes \
     -DMPPP_ENABLE_IPO=yes \
-    $AR_CMAKE_SETTING \
-    $RANLIB_CMAKE_SETTING \
     -DMPPP_INSTALL_LIBDIR=lib \
     ..
 
 make -j${CPU_COUNT} VERBOSE=1
 
-ctest --output-on-failure -E integer_hash
+if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
+ctest -j${CPU_COUNT} --output-on-failure
+fi
 
 make install
